==> symbol-processing-aa-embeddable-2.1.0-1.0.29-sources.jar: com/intellij/psi/impl/source/resolve/reference/impl/manipulators/PsiDocTagValueManipulator.java <==
/*
 * Copyright 2000-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ksp.com.intellij.psi.impl.source.resolve.reference.impl.manipulators;

import ksp.com.intellij.openapi.util.TextRange;
import ksp.com.intellij.psi.AbstractElementManipulator;
import ksp.com.intellij.psi.JavaPsiFacade;
import ksp.com.intellij.psi.PsiElement;
import ksp.com.intellij.psi.javadoc.PsiDocTag;
import ksp.com.intellij.util.IncorrectOperationException;
import ksp.org.jetbrains.annotations.NotNull;

/**
 * @author Gregory.Shrago
 */
public class PsiDocTagValueManipulator extends AbstractElementManipulator<PsiDocTag> {

  @Override
  public PsiDocTag handleContentChange(@NotNull PsiDocTag tag, @NotNull TextRange range, String newContent) throws IncorrectOperationException {
    final StringBuilder replacement = new StringBuilder( tag.getText() );

    replacement.replace(
      range.getStartOffset(),
      range.getEndOffset(),
      newContent
    );
    return (PsiDocTag)tag.replace(JavaPsiFacade.getElementFactory(tag.getProject()).createDocTagFromText(replacement.toString()));
  }

  @NotNull
  @Override
  public TextRange getRangeInElement(@NotNull final PsiDocTag tag) {
    final PsiElement[] elements = tag.getDataElements();
    if (elements.length == 0) {
      final PsiElement name = tag.getNameElement();
      final int offset = name.getStartOffsetInParent() + name.getTextLength();
      return new TextRange(offset, offset);
    }
    final PsiElement first = elements[0];
    final PsiElement last = elements[elements.length - 1];
    return new TextRange(first.getStartOffsetInParent(), last.getStartOffsetInParent()+last.getTextLength());
  }
}

==> symbol-processing-aa-embeddable-2.2.0-2.0.2-sources.jar: com/intellij/psi/impl/source/resolve/reference/impl/manipulators/PsiDocTagValueManipulator.java <==
/*
 * Copyright 2000-2014 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ksp.com.intellij.psi.impl.source.resolve.reference.impl.manipulators;

import ksp.com.intellij.openapi.util.TextRange;
import ksp.com.intellij.psi.AbstractElementManipulator;
import ksp.com.intellij.psi.JavaPsiFacade;
import ksp.com.intellij.psi.PsiElement;
import ksp.com.intellij.psi.javadoc.PsiDocTag;
import ksp.com.intellij.util.IncorrectOperationException;
import ksp.org.jetbrains.annotations.NotNull;

/**
 * @author Gregory.Shrago
 */
public final class PsiDocTagValueManipulator extends AbstractElementManipulator<PsiDocTag> {

  @Override
  public PsiDocTag handleContentChange(@NotNull PsiDocTag tag, @NotNull TextRange range, String newContent) throws IncorrectOperationException {
    final StringBuilder replacement = new StringBuilder( tag.getText() );

    replacement.replace(
      range.getStartOffset(),
      range.getEndOffset(),
      newContent
    );
    return (PsiDocTag)tag.replace(JavaPsiFacade.getElementFactory(tag.getProject()).createDocTagFromText(replacement.toString()));
  }

  @NotNull
  @Override
  public TextRange getRangeInElement(@NotNull final PsiDocTag tag) {
    final PsiElement[] elements = tag.getDataElements();
    if (elements.length == 0) {
      final PsiElement name = tag.getNameElement();
      final int offset = name.getStartOffsetInParent() + name.getTextLength();
      return new TextRange(offset, offset);
    }
    final PsiElement first = elements[0];
    final PsiElement last = elements[elements.length - 1];
    return new TextRange(first.getStartOffsetInParent(), last.getStartOffsetInParent()+last.getTextLength());
  }
}
